@@ -557,8 +557,11 @@ def get_best_trial_number_nob(result_,nob_group="0.0-0.15"):
     final_result = result_[(result_.bias_group==nob_group) & (result_.overfitting==False)].sort_values(by=['mean_valid_score'], ascending=False)
     if len(final_result)==0:
         final_result = result_[result_.overfitting==False].sort_values(by=['mean_valid_score'], ascending=False)
-        trial_number = final_result['trial_number'].iloc[0]
-        return trial_number
+        if len(final_result)==0:
+            return None
+        else:
+            trial_number = final_result['trial_number'].iloc[0]        
+            return trial_number
     else:
         trial_number = final_result['trial_number'].iloc[0]
         return trial_number
